@@ -221,7 +221,7 @@ int cb_check_data(spctx_t* ctx)
         sp_messagex(ctx, LOG_WARNING, "no filter command specified. passing message through");
         
         if(sp_cache_data(ctx) == -1 ||
-           sp_done_data(ctx) == -1)
+           sp_done_data(ctx, NULL) == -1)
             return -1;  /* Message already printed */
             
         return 0;
@@ -520,7 +520,7 @@ static int process_file_command(spctx_t* sp)
     /* A successful response */    
     if(WEXITSTATUS(status) == 0)
     {
-        if(sp_done_data(sp) == -1)
+        if(sp_done_data(sp, NULL) == -1)
             RETURN(-1); /* message already printed */
 
         sp_add_log(sp, "status=", "FILTERED");        
@@ -764,7 +764,7 @@ static int process_pipe_command(spctx_t* sp)
     /* A successful response */    
     if(WEXITSTATUS(status) == 0)
     {
-        if(sp_done_data(sp) == -1)
+        if(sp_done_data(sp, NULL) == -1)
             RETURN(-1); /* message already printed */
 
         sp_add_log(sp, "status=", "FILTERED");        
@@ -865,6 +865,7 @@ static int wait_process(spctx_t* sp, pid_t pid, int* status)
 {
     /* We poll x times a second */
     int waits = g_pxstate.timeout.tv_sec * (1000 / POLL_TIME);
+    *status = 0; 
     
     while(waits > 0)
     {
@@ -873,7 +874,7 @@ static int wait_process(spctx_t* sp, pid_t pid, int* status)
         case 0:
             break;
         case -1:
-            if(errno != ECHILD || errno != ESRCH)
+            if(errno != ECHILD && errno != ESRCH)
             {
                 sp_message(sp, LOG_CRIT, "error waiting on process");
                 return -1;
